@@ -1,10 +1,10 @@
+from __future__ import annotations
+
 from media_platform.lang.serialization import Deserializable
 
 
 class Color(Deserializable):
-    def __init__(self, r, g, b, pixel_fraction, score):
-        # type: (int, int, int, float, float) -> None
-        super(Color, self).__init__()
+    def __init__(self, r: int, g: int, b: int, pixel_fraction: float, score: float):
         self.r = r
         self.g = g
         self.b = b
@@ -12,6 +12,5 @@ class Color(Deserializable):
         self.score = score
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> Color
+    def deserialize(cls, data: dict) -> Color:
         return Color(data['r'], data['g'], data['b'], data['pixelFraction'], data['score'])
